@@ -53,19 +53,23 @@
  * traps (silently) do not happen.
  *
  * The Linux kernel and the Solarix x86 set the "AM".  The Windows and
- * OX X do not.  The *BSD behavior is unknown, though suspecting they do.
+ * OS X do not.  The *BSD behavior is unknown, though suspecting they do.
  *
  * http://en.wikipedia.org/wiki/Control_register
  * http://en.wikipedia.org/wiki/FLAGS_register_(computing)
  */
 #ifdef SRL_X86_OR_X64_CPU
-#  if __x86_64__ || __x86_64
+#  if defined(__x86_64__) || defined(__x86_64)
 #    define SRL_TRY_ENABLE_STRICT_ALIGN() asm("pushf\norl $0x40000, (%rsp)\npopf")
-#  elif __i386__ || __i386
+#  elif defined(__i386__) || defined(__i386)
 #    define SRL_TRY_ENABLE_STRICT_ALIGN() asm("pushf\norl $0x40000, (%esp)\npopf")
 #  endif
 #else
 #  define SRL_TRY_ENABLE_STRICT_ALIGN() (void)0
 #endif
 
+/* define constant for other code to use in preallocations or buffer space
+ * assertions */
+#define SRL_MAX_VARINT_LENGTH 11
+
 #endif
